from enum import Enum


class EnumJobResultName(Enum):
    core_ping = "core.ping"
    core_system = "core.system"
    core_kill = "core.kill"
    core_killall = "core.killall"
    core_state = "core.state"
    core_reboot = "core.reboot"
    info_cpu = "info.cpu"
    info_disk = "info.disk"
    info_mem = "info.mem"
    info_nic = "info.nic"
    info_os = "info.os"
    container_create = "container.create"
    container_list = "container.list"
    container_dispatch = "container.dispatch"
    container_terminate = "container.terminate"
    bridge_create = "bridge.create"
    bridge_list = "bridge.list"
    bridge_delete = "bridge.delete"
    disk_list = "disk.list"
    disk_mktable = "disk.mktable"
    disk_mkpart = "disk.mkpart"
    disk_rmpart = "disk.rmpart"
    disk_mount = "disk.mount"
    disk_umount = "disk.umount"
    btrfs_create = "btrfs.create"
    btrfs_list = "btrfs.list"
    btrfs_subvol_create = "btrfs.subvol_create"
    btrfs_subvol_list = "btrfs.subvol_list"
    btrfs_subvol_delete = "btrfs.subvol_delete"
